@@ -1,5 +1,7 @@
 import tkinter as tk
 from tkinter import scrolledtext
+from tkinter import font
+from tkinter import ttk
 import sys
 import threading
 import queue
@@ -41,14 +43,39 @@ def openingLine(q):
     textbox.insert(tk.END, "Post Window for SuperCollider:\n")
     root.after(WINDOW_INTERVAL, processText, q)
 
+def zoomIn():
+    font.configure(size=font.cget("size") + 2)
+
+def zoomOut():
+    font.configure(size=font.cget("size") - 2)
+
 # Main code to run
 q = queue.Queue()
 t = threading.Thread(target=addToQueue, args=(q,))
 t.daemon = True
 root = tk.Tk()
 root.resizable(True, True)
-textbox = scrolledtext.ScrolledText(root)
-textbox.pack()
+
+# Font buttons
+font = font.Font(family="Courier", size=14)
+button_frame = tk.Frame(root)
+button_frame.pack(fill="x")
+
+# Top label and buttons
+label=tk.Label(button_frame, text="SC Post Window")
+zin = tk.Button(button_frame, text="Zoom In", command=zoomIn)
+zout = tk.Button(button_frame, text="Zoom Out", command=zoomOut)
+label.pack(side="left")
+zin.pack(side="left")
+zout.pack(side="left")
+
+# Horizontal Separator
+separator = ttk.Separator(root, orient="horizontal")
+separator.pack(side="top", fill="x")
+
+# Textbox
+textbox = scrolledtext.ScrolledText(root, font=font)
+textbox.pack(expand=True, fill="both")
 root.after(0, openingLine, q)
 
 # Run display
